[]Enum matrix_sdk::api::r0::filter::LazyLoadOptions

pub enum LazyLoadOptions {
    Disabled,
    Enabled {
        include_redundant_members: bool,
    },
}

Specifies options for lazy-loading membership events on supported endpoints

Variants

Disabled

Disables lazy-loading of membership events.

Enabled

Enables lazy-loading of events.

Fields of Enabled

include_redundant_members: bool

If true, sends all membership events for all events, even if they have already been sent to the client. Defaults to false.

Implementations

impl LazyLoadOptions

pub fn is_disabled(&self) -> bool

Returns true is self is Disabled.