[]Struct matrix_sdk::api::r0::sync::sync_events::LeftRoom

#[non_exhaustive]pub struct LeftRoom {
    pub timeline: Timeline,
    pub state: State,
    pub account_data: AccountData,
}

Historical updates to left rooms.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
timeline: Timeline

The timeline of messages and state changes in the room up to the point when the user left.

state: State

The state updates for the room up to the start of the timeline.

account_data: AccountData

The private data that this user has attached to this room.

Implementations

impl LeftRoom

pub fn new() -> LeftRoom

Creates an empty LeftRoom.

pub fn is_empty(&self) -> bool

Returns true if there are updates in the room.