SsoLoginBuilder

Struct SsoLoginBuilder 

pub struct SsoLoginBuilder<F> { /* private fields */ }
Available on crate feature sso-login only.
Builder type used to configure optional settings for logging in via SSO.

Created with MatrixAuth::login_sso. Finalized with .send().

Implementations

Source

impl<F, Fut> SsoLoginBuilder<F>
where F: FnOnce(String) -> Fut + Send, Fut: Future<Output = Result<()>> + Send,

pub fn device_id(self, value: &str) -> Self

Set the device ID.

The device ID is a unique ID that will be associated with this session. If not set, the homeserver will create one. Can be an existing device ID from a previous login call. Note that this should be done only if the client also holds the corresponding encryption keys.

pub fn initial_device_display_name(self, value: &str) -> Self

Set the initial device display name.

The device display name is the public name that will be associated with the device ID. Only necessary the first time you login with this device ID. It can be changed later.

pub fn server_builder(self, builder: LocalServerBuilder) -> Self

Customize the settings used to construct the server where the end-user will be redirected.

If this is not set, the default settings of LocalServerBuilder will be used.

pub fn identity_provider_id(self, value: &str) -> Self

Set the ID of the identity provider to log in with.

pub fn request_refresh_token(self) -> Self

Advertise support for refreshing access tokens.

By default, the Client won’t handle refreshing access tokens, so Client::refresh_access_token() or MatrixAuth::refresh_access_token() needs to be called manually.

This behavior can be changed by calling handle_refresh_tokens() when building the Client.

Note that refreshing access tokens might not be supported or might be enforced by the homeserver regardless of this setting.

pub async fn send(self) -> Result<Response>

Send the login request.

Instead of calling this function and .awaiting its return value, you can also .await the SsoLoginBuilder directly.

Panics

Panics if a session was already restored or logged in.