pub struct GrantLoginWithGeneratedQrCode<'a> { /* private fields */ }Available on crate feature
e2e-encryption only.Expand description
Named future for granting login by generating a QR code on this, existing, device to be scanned by the other, new, device.
Implementations
Sourceimpl GrantLoginWithGeneratedQrCode<'_>
impl GrantLoginWithGeneratedQrCode<'_>
Sourcepub fn subscribe_to_progress(
&self,
) -> impl Stream<Item = GrantLoginProgress<GeneratedQrProgress>> + use<>
pub fn subscribe_to_progress( &self, ) -> impl Stream<Item = GrantLoginProgress<GeneratedQrProgress>> + use<>
Subscribe to the progress of QR code login.
It’s necessary to subscribe to this to capture the QR code in order to
display it to the other device, to feed the CheckCode entered by the
user back in and to obtain the verification URL for consenting to
the login.