LoginWithGeneratedQrCode

Struct LoginWithGeneratedQrCode 

pub struct LoginWithGeneratedQrCode<'a> { /* private fields */ }
Available on crate feature e2e-encryption only.
Named future for logging in by generating a QR code with the OAuth::login_with_qr_code() method.

Implementations

Source

impl LoginWithGeneratedQrCode<'_>

pub fn subscribe_to_progress( &self, ) -> impl Stream<Item = LoginProgress<GeneratedQrProgress>> + use<>

Subscribe to the progress of QR code login.

It’s necessary to subscribe to this to show the QR code to the existing device so it can send the check code back to this device.