pub enum VerificationLevel {
UnverifiedIdentity,
VerificationViolation,
UnsignedDevice,
None(DeviceLinkProblem),
MismatchedSender,
}Expand description
The sub-enum containing detailed information on why a message is considered to be unverified.
Variants
UnverifiedIdentity
The message was sent by a user identity we have not verified.
VerificationViolation
The message was sent by a user identity we have not verified, but the user was previously verified.
UnsignedDevice
The message was sent by a device not linked to (signed by) any user identity.
None(DeviceLinkProblem)
We weren’t able to link the message back to any device. This might be because the message claims to have been sent by a device which we have not been able to obtain (for example, because the device was since deleted) or because the key to decrypt the message was obtained from an insecure source.
MismatchedSender
The sender field on the event does not match the owner of the device
that established the Megolm session.