ThreadSummary

Struct ThreadSummary 

pub struct ThreadSummary {
    pub latest_reply: Option<OwnedEventId>,
    pub num_replies: u32,
}
A simplified thread summary.

A thread summary contains useful information pertaining to a thread, and that would be usually attached in clients to a thread root event (i.e. the first event from which the thread originated), along with links into the thread’s view. This summary may include, for instance:

  • the number of replies to the thread,
  • the full event of the latest reply to the thread,
  • whether the user participated or not to this thread.

Fields

latest_reply: Option<OwnedEventId>

The event id for the latest reply to the thread.

num_replies: u32

The number of replies to the thread.

This doesn’t include the thread root event itself. It can be zero if no events in the thread are considered to be meaningful (or they’ve all been redacted).