pub enum EnableBackupError {
InconsistentBackupDecryptionKey,
Error(Error),
}Available on crate feature
e2e-encryption only.Expand description
An error that happened while we were attempting to enable key backups.
Variants
InconsistentBackupDecryptionKey
The private decryption key we found does not match the public key for the enabled backup.
Error(Error)
A general error occurred while enabling key backup.