pub enum CryptoStoreError {
AccountUnset,
Io(Error),
UnpicklingError,
Pickle(PickleError),
SessionCreation(SessionCreationError),
IdentifierValidation(Error),
Serialization(Error),
UnsupportedDatabaseVersion(usize, usize),
Backend(Box<dyn Error + Send + Sync + 'static, Global>),
}Available on crate feature
e2e-encryption only.Expand description
The crypto store’s error type.
Variants
AccountUnset
The account that owns the sessions, group sessions, and devices wasn’t found.
Io(Error)
An IO error occurred.
UnpicklingError
Failed to decrypt an pickled object.
Pickle(PickleError)
Failed to decrypt an pickled object.
SessionCreation(SessionCreationError)
The received room key couldn’t be converted into a valid Megolm session.
IdentifierValidation(Error)
A Matrix identifier failed to be validated.
Serialization(Error)
The store failed to (de)serialize a data type.
UnsupportedDatabaseVersion(usize, usize)
The database format has changed in a backwards incompatible way.
Backend(Box<dyn Error + Send + Sync + 'static, Global>)
A problem with the underlying database backend
Implementations
impl CryptoStoreError
impl CryptoStoreError