pub enum KeyExportError {
InvalidHeaders,
UnsupportedVersion,
InvalidMac,
InvalidUtf8(FromUtf8Error),
Json(Error),
Decode(DecodeError),
Io(Error),
}Available on crate feature
e2e-encryption only.Expand description
Error representing a failure during key export or import.
Variants
InvalidHeaders
The key export doesn’t contain valid headers.
UnsupportedVersion
The key export has been encrypted with an unsupported version.
InvalidMac
The MAC of the encrypted payload is invalid.
InvalidUtf8(FromUtf8Error)
The decrypted key export isn’t valid UTF-8.
Json(Error)
The decrypted key export doesn’t contain valid JSON.
Decode(DecodeError)
The key export string isn’t valid base64.
Io(Error)
The key export doesn’t all the required fields.