Enum matrix_sdk::encryption::MegolmError
[−]pub enum MegolmError {
EventError(EventError),
JsonError(Error),
MissingRoomKey,
Decode(DecodeError),
EncryptionNotEnabled,
Decryption(DecryptionError),
Store(CryptoStoreError),
}Available on crate feature
e2e-encryption only.Expand description
Error representing a failure during a group encryption operation.
Variants
EventError(EventError)
The event that should have been decrypted is malformed.
JsonError(Error)
The received decrypted event couldn’t be deserialized.
MissingRoomKey
Decryption failed because we’re missing the room key that was to encrypt the event.
Decode(DecodeError)
The encrypted megolm message couldn’t be decoded.
EncryptionNotEnabled
The room where a group session should be shared is not encrypted.
Decryption(DecryptionError)
The event could not have been decrypted.
Store(CryptoStoreError)
The storage layer returned an error.