Enum matrix_sdk::encryption::OlmError
[−]pub enum OlmError {
EventError(EventError),
JsonError(Error),
Decryption(DecryptionError),
SessionCreation(SessionCreationError),
SessionExport(SessionExportError),
Store(CryptoStoreError),
SessionWedged(OwnedUserId, Curve25519PublicKey),
ReplayedMessage(OwnedUserId, Curve25519PublicKey),
MissingSession,
}Available on crate feature
e2e-encryption only.Expand description
Error representing a failure during a device to device cryptographic operation.
Variants
EventError(EventError)
The event that should have been decrypted is malformed.
JsonError(Error)
The received decrypted event couldn’t be deserialized.
Decryption(DecryptionError)
The event could not have been decrypted.
SessionCreation(SessionCreationError)
The received room key couldn’t be converted into a valid Megolm session.
SessionExport(SessionExportError)
The room key that should be exported can’t be converted into a
m.forwarded_room_key event.
Store(CryptoStoreError)
The storage layer returned an error.
SessionWedged(OwnedUserId, Curve25519PublicKey)
The session with a device has become corrupted.
ReplayedMessage(OwnedUserId, Curve25519PublicKey)
An Olm message got replayed while the Olm ratchet has already moved forward.
MissingSession
Encryption failed because the device does not have a valid Olm session with us.