pub enum SecretImportError {
Key(KeyError),
MismatchedPublicKeys,
Store(CryptoStoreError),
}Available on crate feature
e2e-encryption only.Expand description
Error describing what went wrong when importing private cross signing keys or the key backup key.
Variants
Key(KeyError)
The key that we tried to import was invalid.
MismatchedPublicKeys
The public key of the imported private key doesn’t match to the public key that was uploaded to the server.
Store(CryptoStoreError)
The new version of the identity couldn’t be stored.