Enum matrix_sdk::encryption::identities::ManualVerifyError
source · [−]pub enum ManualVerifyError {
Http(HttpError),
Signature(SignatureError),
}Available on crate feature
e2e-encryption only.Expand description
Error for the manual verification step, when we manually sign users or devices.
Variants
Http(HttpError)
Error that happens when we try to upload the user or device signature.
Signature(SignatureError)
Error that happens when we try to sign the user or device.