Struct matrix_sdk::encryption::identities::MasterPubkey
[−]pub struct MasterPubkey(_);Available on crate feature
e2e-encryption only.Expand description
Wrapper for a cross signing key marking it as the master key.
Master keys are used to sign other cross signing keys, the self signing and user signing keys of an user will be signed by their master key.
Implementations
impl MasterPubkey
impl MasterPubkey
pub fn user_id(&self) -> &UserId
pub fn user_id(&self) -> &UserId
Get the user id of the master key’s owner.
pub fn keys(&self) -> &SigningKeys<OwnedDeviceKeyId>
pub fn keys(&self) -> &SigningKeys<OwnedDeviceKeyId>
Get the keys map of containing the master keys.
pub fn usage(&self) -> &[KeyUsage]
pub fn usage(&self) -> &[KeyUsage]
Get the list of KeyUsage that is set for this key.
pub fn signatures(&self) -> &Signatures
pub fn signatures(&self) -> &Signatures
Get the signatures map of this cross signing key.
pub fn get_key(&self, key_id: &DeviceKeyId) -> Option<&SigningKey>
pub fn get_key(&self, key_id: &DeviceKeyId) -> Option<&SigningKey>
Get the master key with the given key id.
Arguments
key_id- The id of the key that should be fetched.
pub fn get_first_key(&self) -> Option<Ed25519PublicKey>
pub fn get_first_key(&self) -> Option<Ed25519PublicKey>
Get the first available master key.
There’s usually only a single master key so this will usually fetch the only key.