pub struct OAuthCrossSigningResetInfo {
pub approval_url: Url,
}Available on crate feature
e2e-encryption only.Expand description
OAuth 2.0 specific information about the required authentication for the upload of cross-signing keys.
Fields
approval_url: UrlThe URL where the user can approve the reset of the cross-signing keys.