pub enum ScanError {
    Store(CryptoStoreError),
    KeyMismatch {
        expected: String,
        found: String,
    },
    MissingCrossSigningIdentity(OwnedUserId),
    MissingDeviceKeys(OwnedUserId, OwnedDeviceId),
    FlowIdMismatch {
        expected: String,
        found: String,
    },
}
Available on crate features e2e-encryption and qrcode only.
An error for the different failure modes that can happen during the validation of a scanned QR code.

Variants

Store(CryptoStoreError)

An IO error inside the crypto store happened during the validation of the QR code scan.

KeyMismatch

Fields

expected: String

The expected ed25519 key.

found: String

The ed25519 key that we got.

A key mismatch happened during the validation of the QR code scan.

MissingCrossSigningIdentity(OwnedUserId)

One of the users that is participating in this verification doesn’t have a valid cross signing identity.

MissingDeviceKeys(OwnedUserId, OwnedDeviceId)

The device of the user that is participating in this verification doesn’t have a valid device key.

FlowIdMismatch

Fields

expected: String

The expected verification flow id.

found: String

The verification flow id that we instead got.

The ID uniquely identifying this verification flow didn’t match to the one that has been scanned.