Enum matrix_sdk::encryption::vodozemac::DecodeError
[−]pub enum DecodeError {
MessageType(usize),
MissingVersion,
MessageTooShort(usize),
InvalidVersion(u8, u8),
InvalidKey(KeyError),
InvalidMacLength(usize, usize),
Signature(SignatureError),
ProtoBufError(DecodeError),
Base64(DecodeError),
}Available on crate feature
e2e-encryption only.Expand description
Error type describing the different ways message decoding can fail.
Variants
MessageType(usize)
The Olm message has an invalid type.
MissingVersion
The message is missing a valid version.
MessageTooShort(usize)
The message doesn’t have enough data to be correctly decoded.
InvalidVersion(u8, u8)
The message has a unsupported version.
InvalidKey(KeyError)
An embedded public key couldn’t be decoded.
InvalidMacLength(usize, usize)
The embedded message authentication code couldn’t be decoded.
Signature(SignatureError)
An embedded signature couldn’t be decoded.
ProtoBufError(DecodeError)
The message couldn’t be decoded as a valid protocol buffer message.
Base64(DecodeError)
The message wasn’t valid base64.