Enum matrix_sdk::encryption::vodozemac::KeyError
[−]pub enum KeyError {
Base64Error(DecodeError),
InvalidKeyLength(usize),
Signature(SignatureError),
NonContributoryKey,
}Available on crate feature
e2e-encryption only.Expand description
Error type describing failures that can happen when we try decode or use a cryptographic key.
Variants
Base64Error(DecodeError)
InvalidKeyLength(usize)
Signature(SignatureError)
NonContributoryKey
At least one of the keys did not have contributory behaviour and the resulting shared secret would have been insecure.