pub enum MegolmDecryptionError {
Signature(SignatureError),
InvalidMAC(MacError),
InvalidMACLength(usize, usize),
InvalidPadding(UnpadError),
UnknownMessageIndex(u32, u32),
}Available on crate feature
e2e-encryption only.Expand description
Error type for Megolm-based decryption failuers.
Variants
Signature(SignatureError)
The signature on the message was invalid.
InvalidMAC(MacError)
The message authentication code of the message was invalid.
InvalidMACLength(usize, usize)
The length of the message authentication code of the message did not match our expected length.
InvalidPadding(UnpadError)
The ciphertext of the message isn’t padded correctly.
UnknownMessageIndex(u32, u32)
The session is missing the correct message key to decrypt the message, The Session has been ratcheted forwards and the message key isn’t available anymore.