pub enum OlmDecryptionError {
InvalidMAC(MacError),
InvalidMACLength(usize, usize),
InvalidPadding(UnpadError),
MissingMessageKey(u64),
TooBigMessageGap(u64, u64),
}Available on crate feature
e2e-encryption only.Expand description
Error type for Olm-based decryption failuers.
Variants
InvalidMAC(MacError)
The message authentication code of the message was invalid.
InvalidMACLength(usize, usize)
The length of the message authentication code of the message did not match our expected length.
InvalidPadding(UnpadError)
The ciphertext of the message isn’t padded correctly.
MissingMessageKey(u64)
The session is missing the correct message key to decrypt the message, either because it was already used up, or because the Session has been ratcheted forwards and the message key has been discarded.
TooBigMessageGap(u64, u64)
Too many messages have been skipped to attempt decrypting this message.