pub enum OlmSessionCreationError {
MissingOneTimeKey(Curve25519PublicKey),
MismatchedIdentityKey(Curve25519PublicKey, Curve25519PublicKey),
Decryption(DecryptionError),
}Available on crate feature
e2e-encryption only.Expand description
Error describing failure modes when creating a Olm Session from an incoming Olm message.
Variants
MissingOneTimeKey(Curve25519PublicKey)
The pre-key message contained an unknown one-time key. This happens either because we never had such a one-time key, or because it has already been used up.
MismatchedIdentityKey(Curve25519PublicKey, Curve25519PublicKey)
The pre-key message contains a curve25519 identity key that doesn’t match to the identity key that was given.
Decryption(DecryptionError)
The pre-key message that was used to establish the Session couldn’t be decrypted. The message needs to be decryptable, otherwise we will have created a Session that wasn’t used to encrypt the pre-key message.