Enum matrix_sdk::ImageError
source · [−]pub enum ImageError {
Proc(ImageError),
FormatNotSupported,
ThumbnailBiggerThanOriginal,
}Available on crate feature
image-proc only.Expand description
All possible errors that can happen during image processing.
Variants
Proc(ImageError)
Error processing the image data.
FormatNotSupported
The image format is not supported.
ThumbnailBiggerThanOriginal
The thumbnail size is bigger than the original image.