pub enum RoomDisplayName {
Named(String),
Aliased(String),
Calculated(String),
EmptyWas(String),
Empty,
}Expand description
The name of the room, either from the metadata or calculated according to matrix specification
Variants
Named(String)
The room has been named explicitly as
Aliased(String)
The room has a canonical alias that should be used
Calculated(String)
The room has not given an explicit name but a name could be calculated
EmptyWas(String)
The room doesn’t have a name right now, but used to have one e.g. because it was a DM and everyone has left the room
Empty
No useful name could be calculated or ever found
Implementations
Sourceimpl RoomDisplayName
impl RoomDisplayName
Sourcepub fn to_room_alias_name(&self) -> String
pub fn to_room_alias_name(&self) -> String
Transforms the current display name into the name part of a
RoomAliasId.