pub enum ThreadEventCacheUpdate {
UpdateTimelineEvents(TimelineVectorDiffs),
AddReadReceiptEvent {
event: ReceiptEventContent,
},
}Expand description
An update related to events happened in a thread.
Variants
UpdateTimelineEvents(TimelineVectorDiffs)
The thread has received updates for the timeline as diffs.
AddReadReceiptEvent
The thread has received a new read receipt event.
Fields

event: ReceiptEventContentThe event containing the receipts.