EventFocusedCache

Struct EventFocusedCache 

pub struct EventFocusedCache { /* private fields */ }
A cache for an event-focused timeline.

This represents a timeline centred around a specific event (e.g., from a permalink), supporting both forward and backward pagination. The focused event may be part of a thread, in which case pagination will use the /relations API instead of /messages.

Pagination tokens are stored as Gap items in the linked chunk itself:

  • A gap at the front (first position) contains the backward pagination token.
  • A gap at the back (last position) contains the forward pagination token.

This is a shallow data structure, and can be cloned cheaply.

Implementations

Source

impl EventFocusedCache

pub async fn events(&self) -> Result<Vec<Event>>

Read all current events.

Use EventFocusedCache::subscribe to get all current events, plus a subscriber.

pub async fn subscribe( &self, ) -> Result<(Vec<Event>, Receiver<TimelineVectorDiffs>)>

Subscribe to updates from this event-focused timeline.

pub async fn hit_timeline_start(&self) -> Result<bool>

Check if we’ve hit the start of the timeline (no more backward pagination possible).

pub async fn hit_timeline_end(&self) -> Result<bool>

Check if we’ve hit the end of the timeline (no more forward pagination possible).

pub async fn paginate_backwards( &self, num_events: u16, ) -> Result<PaginationResult>

Paginate backwards in this event-focused timeline, be it room or thread pagination depending on the mode.

pub async fn paginate_forwards( &self, num_events: u16, ) -> Result<PaginationResult>

Paginate forwards in this event-focused timeline, be it room or thread pagination depending on the mode.

pub async fn thread_root(&self) -> Result<Option<OwnedEventId>>

Get the thread root event ID if this linked chunk is in thread mode.