pub struct ThreadPagination(/* private fields */);Expand description
An API object to run pagination queries on a ThreadEventCache.
Implementations
Sourceimpl ThreadPagination
impl ThreadPagination
Sourcepub async fn run_backwards_until(
&self,
num_requested_events: u16,
) -> Result<BackPaginationOutcome>
pub async fn run_backwards_until( &self, num_requested_events: u16, ) -> Result<BackPaginationOutcome>
Starts a back-pagination for the requested number of events.
This automatically takes care of waiting for a pagination token from sync, if we haven’t done that before.
It will run multiple back-paginations until one of these two conditions is met:
- either we’ve reached the start of the timeline,
- or we’ve obtained enough events to fulfill the requested number of events.
Sourcepub async fn run_backwards_once(
&self,
batch_size: u16,
) -> Result<BackPaginationOutcome>
pub async fn run_backwards_once( &self, batch_size: u16, ) -> Result<BackPaginationOutcome>
Run a single back-pagination for the requested number of events.
This automatically takes care of waiting for a pagination token from sync, if we haven’t done that before.