[−]Type Definition matrix_sdk::events::call::answer::AnswerEvent
type AnswerEvent = MessageEvent<AnswerEventContent>;
This event is sent by the callee when they wish to answer the call.
type AnswerEvent = MessageEvent<AnswerEventContent>;
This event is sent by the callee when they wish to answer the call.