[]Struct matrix_sdk::events::call::invite::InviteEventContent

pub struct InviteEventContent {
    pub call_id: String,
    pub lifetime: UInt,
    pub offer: SessionDescription,
    pub version: UInt,
}

The payload for InviteEvent.

Fields

call_id: String

A unique identifer for the call.

lifetime: UInt

The time in milliseconds that the invite is valid for. Once the invite age exceeds this value, clients should discard it. They should also no longer show the call as awaiting an answer in the UI.

offer: SessionDescription

The session description object. The session description type must be offer.

version: UInt

The version of the VoIP specification this messages adheres to.

Implementations

impl InviteEventContent

pub fn redact(self, version: RoomVersionId) -> RedactedInviteEventContent

Transforms the full event content into a redacted content according to spec.