[−]Type Definition matrix_sdk::events::direct::DirectEvent
type DirectEvent = BasicEvent<DirectEventContent>;
Informs the client about the rooms that are considered direct by a user.
type DirectEvent = BasicEvent<DirectEventContent>;
Informs the client about the rooms that are considered direct by a user.