[]Struct matrix_sdk::events::key::verification::request::RequestToDeviceEventContent

pub struct RequestToDeviceEventContent {
    pub from_device: Box<DeviceId, Global>,
    pub transaction_id: String,
    pub methods: Vec<VerificationMethod, Global>,
    pub timestamp: SystemTime,
}

The payload for RequestEvent.

Fields

from_device: Box<DeviceId, Global>

The device ID which is initiating the request.

transaction_id: String

An opaque identifier for the verification request.

Must be unique with respect to the devices involved.

methods: Vec<VerificationMethod, Global>

The verification methods supported by the sender.

timestamp: SystemTime

The time in milliseconds for when the request was made.

If the request is in the future by more than 5 minutes or more than 10 minutes in the past, the message should be ignored by the receiver.