[]Struct matrix_sdk::events::room::create::CreateEventContent

#[non_exhaustive]pub struct CreateEventContent {
    pub creator: UserId,
    pub federate: bool,
    pub room_version: RoomVersionId,
    pub predecessor: Option<PreviousRoom>,
}

The payload for CreateEvent.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
creator: UserId

The user_id of the room creator. This is set by the homeserver.

federate: bool

Whether or not this room's data should be transferred to other homeservers.

room_version: RoomVersionId

The version of the room. Defaults to "1" if the key does not exist.

predecessor: Option<PreviousRoom>

A reference to the room this room replaces, if the previous room was upgraded.

Implementations

impl CreateEventContent

pub fn new(creator: UserId) -> CreateEventContent

Creates a new CreateEventContent with the given creator.

impl CreateEventContent

pub fn redact(self, version: RoomVersionId) -> RedactedCreateEventContent

Transforms the full event content into a redacted content according to spec.