[]Type Definition matrix_sdk::events::room::create::CreateEvent

type CreateEvent = StateEvent<CreateEventContent>;

This is the first event in a room and cannot be changed. It acts as the root of all other events.