[]Struct matrix_sdk::events::room::encryption::EncryptionEventContent

#[non_exhaustive]pub struct EncryptionEventContent {
    pub algorithm: EventEncryptionAlgorithm,
    pub rotation_period_ms: Option<UInt>,
    pub rotation_period_msgs: Option<UInt>,
}

The payload for EncryptionEvent.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
algorithm: EventEncryptionAlgorithm

The encryption algorithm to be used to encrypt messages sent in this room.

Must be m.megolm.v1.aes-sha2.

rotation_period_ms: Option<UInt>

How long the session should be used before changing it.

uint!(604800000) (a week) is the recommended default.

rotation_period_msgs: Option<UInt>

How many messages should be sent before changing the session.

uint!(100) is the recommended default.

Implementations

impl EncryptionEventContent

pub fn new(algorithm: EventEncryptionAlgorithm) -> EncryptionEventContent

Creates a new EncryptionEventContent with the given algorithm.

impl EncryptionEventContent

pub fn redact(self, version: RoomVersionId) -> RedactedEncryptionEventContent

Transforms the full event content into a redacted content according to spec.