[−]Type Definition matrix_sdk::events::room::encryption::EncryptionEvent
type EncryptionEvent = StateEvent<EncryptionEventContent>;
Defines how messages sent in this room should be encrypted.
type EncryptionEvent = StateEvent<EncryptionEventContent>;
Defines how messages sent in this room should be encrypted.