[]Struct matrix_sdk::events::room::join_rules::JoinRulesEventContent

#[non_exhaustive]pub struct JoinRulesEventContent {
    pub join_rule: JoinRule,
}

The payload for JoinRulesEvent.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
join_rule: JoinRule

The type of rules used for users wishing to join this room.

Implementations

impl JoinRulesEventContent

pub fn new(join_rule: JoinRule) -> JoinRulesEventContent

Creates a new JoinRulesEventContent with the given rule.

impl JoinRulesEventContent

pub fn redact(self, version: RoomVersionId) -> RedactedJoinRulesEventContent

Transforms the full event content into a redacted content according to spec.