[]Enum matrix_sdk::events::room::message::LimitType

pub enum LimitType {
    MonthlyActiveUser,
    // some variants omitted
}

Types of usage limits.

Variants

MonthlyActiveUser

The server's number of active users in the last 30 days has exceeded the maximum.

New connections are being refused by the server. What defines "active" is left as an implementation detail, however servers are encouraged to treat syncing users as "active".