[]Enum matrix_sdk::events::room::message::MessageEventContent

The payload for MessageEvent.

Variants (Non-exhaustive)

Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

An audio message.

An emote message.

A file message.

An image message.

A location message.

A notice message.

A server notice message.

A text message.

A video message.

A request to initiate a key verification.

Implementations

impl MessageEventContent

pub fn text_plain(body: impl Into<String>) -> MessageEventContent

A convenience constructor to create a plain text message.

pub fn text_html(
    body: impl Into<String>,
    html_body: impl Into<String>
) -> MessageEventContent

A convenience constructor to create an html message.

pub fn notice_plain(body: impl Into<String>) -> MessageEventContent

A convenience constructor to create an plain text notice.

pub fn notice_html(
    body: impl Into<String>,
    html_body: impl Into<String>
) -> MessageEventContent

A convenience constructor to create an html notice.

impl MessageEventContent

pub fn redact(self, version: RoomVersionId) -> RedactedMessageEventContent

Transforms the full event content into a redacted content according to spec.