[]Enum matrix_sdk::events::room::message::MessageFormat

pub enum MessageFormat {
    Html,
    // some variants omitted
}

The format for the formatted representation of a message body.

This type can hold an arbitrary string. To check for events that are not available as a documented variant here, use its string representation, obtained through .as_str().

Variants

Html

HTML.

Implementations

impl MessageFormat

pub fn as_str(&self) -> &str

Creates a string slice from this MessageFormat.