[]Struct matrix_sdk::events::room::message::ImageMessageEventContent

pub struct ImageMessageEventContent {
    pub body: String,
    pub info: Option<Box<ImageInfo, Global>>,
    pub url: Option<String>,
    pub file: Option<Box<EncryptedFile, Global>>,
}

The payload for an image message.

Fields

body: String

A textual representation of the image. This could be the alt text of the image, the filename of the image, or some kind of content description for accessibility e.g. "image attachment."

info: Option<Box<ImageInfo, Global>>

Metadata about the image referred to in url.

url: Option<String>

The URL to the image. Required if the file is unencrypted. The URL (typically MXC URI) to the image.

file: Option<Box<EncryptedFile, Global>>

Required if image is encrypted. Information on the encrypted image.