[]Struct matrix_sdk::events::room::message::KeyVerificationRequestEventContent

pub struct KeyVerificationRequestEventContent {
    pub body: String,
    pub methods: Vec<VerificationMethod, Global>,
    pub from_device: Box<DeviceId, Global>,
    pub to: UserId,
}

The payload for a key verification request message.

Fields

body: String

A fallback message to alert users that their client does not support the key verification framework.

methods: Vec<VerificationMethod, Global>

The verification methods supported by the sender.

from_device: Box<DeviceId, Global>

The device ID which is initiating the request.

to: UserId

The user ID which should receive the request.

Users should only respond to verification requests if they are named in this field. Users who are not named in this field and who did not send this event should ignore all other events that have a m.reference relationship with this event.