[]Struct matrix_sdk::events::room::message::TextMessageEventContent

#[non_exhaustive]pub struct TextMessageEventContent {
    pub body: String,
    pub formatted: Option<FormattedBody>,
    pub relates_to: Option<Relation>,
    pub new_content: Option<Box<MessageEventContent, Global>>,
}

The payload for a text message.

Fields (Non-exhaustive)

Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
body: String

The body of the message.

formatted: Option<FormattedBody>

Formatted form of the message body.

relates_to: Option<Relation>

Information about related messages for rich replies.

new_content: Option<Box<MessageEventContent, Global>>

New content of an edited message.

This should only be set if relates_to is Some(Relation::Replacement(_)).

Implementations

impl TextMessageEventContent

pub fn plain(body: impl Into<String>) -> TextMessageEventContent

A convenience constructor to create a plain text message.

pub fn html(
    body: impl Into<String>,
    html_body: impl Into<String>
) -> TextMessageEventContent

A convenience constructor to create an html message.

pub fn new_plain(body: impl Into<String>) -> TextMessageEventContent

👎 Deprecated:

Renamed to plain

A convenience constructor to create a plain text message.