[−]Type Definition matrix_sdk::events::room::topic::TopicEvent
type TopicEvent = StateEvent<TopicEventContent>;
A topic is a short message detailing what is currently being discussed in the room.
type TopicEvent = StateEvent<TopicEventContent>;
A topic is a short message detailing what is currently being discussed in the room.