[]Struct matrix_sdk::events::room_key_request::RoomKeyRequestToDeviceEventContent

pub struct RoomKeyRequestToDeviceEventContent {
    pub action: Action,
    pub body: Option<RequestedKeyInfo>,
    pub requesting_device_id: Box<DeviceId, Global>,
    pub request_id: String,
}

The payload for RoomKeyRequestEvent.

Fields

action: Action

Whether this is a new key request or a cancellation of a previous request.

body: Option<RequestedKeyInfo>

Information about the requested key.

Required when action is request.

requesting_device_id: Box<DeviceId, Global>

ID of the device requesting the key.

request_id: String

A random string uniquely identifying the request for a key.

If the key is requested multiple times, it should be reused. It should also reused in order to cancel a request.