[]Struct matrix_sdk::events::InvalidInput

pub struct InvalidInput(_);

An error returned when attempting to create an event with data that would make it invalid.

This type is similar to InvalidEvent, but used during the construction of a new event, as opposed to deserialization of an existing event from JSON.