[]Struct matrix_sdk::events::MessageEvent

pub struct MessageEvent<C> where
    C: MessageEventContent
{ pub content: C, pub event_id: EventId, pub sender: UserId, pub origin_server_ts: SystemTime, pub room_id: RoomId, pub unsigned: Unsigned, }

A message event.

MessageEvent implements the comparison traits using only the event_id field, a sorted list would be sorted lexicographically based on the event's EventId.

Fields

content: C

Data specific to the event type.

event_id: EventId

The globally unique event identifier for the user who sent the event.

sender: UserId

The fully-qualified ID of the user who sent this event.

origin_server_ts: SystemTime

Timestamp in milliseconds on originating homeserver when this event was sent.

room_id: RoomId

The ID of the room associated with this event.

unsigned: Unsigned

Additional key-value pairs not signed by the homeserver.