[]Struct matrix_sdk::events::RedactedSyncStateEvent

pub struct RedactedSyncStateEvent<C> where
    C: RedactedStateEventContent
{ pub content: C, pub event_id: EventId, pub sender: UserId, pub origin_server_ts: SystemTime, pub state_key: String, pub unsigned: RedactedSyncUnsigned, }

A redacted state event without a room_id.

RedactedSyncStateEvent implements the comparison traits using only the event_id field, a sorted list would be sorted lexicographically based on the event's EventId.

Fields

content: C

Data specific to the event type.

event_id: EventId

The globally unique event identifier for the user who sent the event.

sender: UserId

The fully-qualified ID of the user who sent this event.

origin_server_ts: SystemTime

Timestamp in milliseconds on originating homeserver when this event was sent.

state_key: String

A unique key which defines the overwriting semantics for this piece of room state.

This is often an empty string, but some events send a UserId to show which user the event affects.

unsigned: RedactedSyncUnsigned

Additional key-value pairs not signed by the homeserver.

Implementations

impl<C> RedactedSyncStateEvent<C> where
    C: RedactedStateEventContent

pub fn into_full_event(self, room_id: RoomId) -> RedactedStateEvent<C>

Convert this sync event into a full event, one with a room_id field.