[]Struct matrix_sdk::events::RedactedSyncUnsigned

pub struct RedactedSyncUnsigned {
    pub redacted_because: Option<Box<SyncRedactionEvent, Global>>,
}

Extra information about a redacted sync event that is not incorporated into the sync event's hash.

Fields

redacted_because: Option<Box<SyncRedactionEvent, Global>>

The event that redacted this event, if any.

Implementations

impl RedactedSyncUnsigned

pub fn is_empty(&self) -> bool

Whether this unsigned data is empty (redacted_because is None).

This method is used to determine whether to skip serializing the unsignedSync field in redacted room events. Do not use it to determine whether an incoming unsignedSync field was present - it could still have been present but contained none of the known fields.

pub fn into_full(self, room_id: RoomId) -> RedactedUnsigned

Convert a RedactedSyncUnsigned into RedactedUnsigned, converting the underlying sync redaction event to a full redaction event (with room_id).