[]Struct matrix_sdk::events::RedactedUnsigned

pub struct RedactedUnsigned {
    pub redacted_because: Option<Box<RedactionEvent, Global>>,
}

Extra information about a redacted event that is not incorporated into the event's hash.

Fields

redacted_because: Option<Box<RedactionEvent, Global>>

The event that redacted this event, if any.

Implementations

impl RedactedUnsigned

pub fn is_empty(&self) -> bool

Whether this unsigned data is empty (redacted_because is None).

This method is used to determine whether to skip serializing the unsigned field in redacted room events. Do not use it to determine whether an incoming unsigned field was present - it could still have been present but contained none of the known fields.