[]Struct matrix_sdk::events::Unsigned

pub struct Unsigned {
    pub age: Option<Int>,
    pub transaction_id: Option<String>,
}

Extra information about an event that is not incorporated into the event's hash.

Fields

age: Option<Int>

The time in milliseconds that has elapsed since the event was sent. This field is generated by the local homeserver, and may be incorrect if the local time on at least one of the two servers is out of sync, which can cause the age to either be negative or greater than it actually is.

transaction_id: Option<String>

The client-supplied transaction ID, if the client being given the event is the same one which sent it.

Implementations

impl Unsigned

pub fn is_empty(&self) -> bool

Whether this unsigned data is empty (all fields are None).

This method is used to determine whether to skip serializing the unsigned field in room events. Do not use it to determine whether an incoming unsigned field was present - it could still have been present but contained none of the known fields.