[−]Type Definition matrix_sdk::events::typing::TypingEvent
type TypingEvent = EphemeralRoomEvent<TypingEventContent>;
Informs the client who is currently typing in a given room.
type TypingEvent = EphemeralRoomEvent<TypingEventContent>;
Informs the client who is currently typing in a given room.