[]Enum matrix_sdk::push::Tweak

#[non_exhaustive]pub enum Tweak {
    Sound(String),
    Highlight(bool),
    Custom {
        name: String,
        value: Box<RawValue, Global>,
    },
}

The set_tweak action.

Variants (Non-exhaustive)

Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sound(String)

A string representing the sound to be played when this notification arrives.

A value of "default" means to play a default sound. A device may choose to alert the user by some other means if appropriate, eg. vibration.

Highlight(bool)

A boolean representing whether or not this message should be highlighted in the UI.

This will normally take the form of presenting the message in a different color and/or style. The UI might also be adjusted to draw particular attention to the room in which the event occurred. If a highlight tweak is given with no value, its value is defined to be true. If no highlight tweak is given at all then the value of highlight is defined to be false.

Custom

A custom tweak

Fields of Custom

name: String

The name of the custom tweak (set_tweak field)

value: Box<RawValue, Global>

The value of the custom tweak