[−]Struct matrix_sdk::push::AnyPushRule
Like SimplePushRule, but may represent any kind of push rule
thanks to pattern and conditions being optional.
To create an instance of this type, use one of its From implementations.
Fields (Non-exhaustive)
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.actions: Vec<Action, Global>The actions to perform when this rule is matched.
default: boolWhether this is a default rule, or has been set explicitly.
enabled: boolWhether the push rule is enabled or not.
rule_id: StringThe ID of this rule.
conditions: Option<Vec<PushCondition, Global>>The conditions that must hold true for an event in order for a rule to be applied to an event. A rule with no conditions always matches.
Only applicable to underride and override rules.
pattern: Option<String>The glob-style pattern to match against. Only applicable to content rules.