[]Struct matrix_sdk::push::UnderridePushRule

pub struct UnderridePushRule(pub ConditionalPushRule);

Wrapper type to disambiguate the kind of the wrapped rule

Implementations

impl UnderridePushRule

Default underrides push rules

pub fn call() -> UnderridePushRule

Matches any incoming VOIP call.

pub fn encrypted_room_one_to_one() -> UnderridePushRule

Matches any encrypted event sent in a room with exactly two members. Unlike other push rules, this rule cannot be matched against the content of the event by nature of it being encrypted. This causes the rule to be an "all or nothing" match where it either matches all events that are encrypted (in 1:1 rooms) or none.

pub fn room_one_to_one() -> UnderridePushRule

Matches any message sent in a room with exactly two members.

pub fn message() -> UnderridePushRule

Matches all chat messages.

pub fn encrypted() -> UnderridePushRule

Matches all encrypted events. Unlike other push rules, this rule cannot be matched against the content of the event by nature of it being encrypted. This causes the rule to be an "all or nothing" match where it either matches all events that are encrypted (in group rooms) or none.