pub enum CallError {
Fetch(Box<Error>),
BadEventType,
DeclineOwnCall,
Deserialize(Error),
}Expand description
An error occurring while interacting with a call/rtc event.
Variants
Fetch(Box<Error>)
We couldn’t fetch the remote notification event.
BadEventType
We tried to decline an event which is not of type m.rtc.notification.
DeclineOwnCall
We tried to decline a call started by ourselves.
Deserialize(Error)
We couldn’t properly deserialize the target event.