Reply

Struct Reply 

pub struct Reply {
    pub event_id: OwnedEventId,
    pub enforce_thread: EnforceThread,
    pub add_mentions: AddMentions,
}
Information needed to reply to an event.

Fields

event_id: OwnedEventId

The event ID of the event to reply to.

enforce_thread: EnforceThread

Whether to enforce a thread relation.

add_mentions: AddMentions

Whether to add intentional Mentions. Might be ignored if the reply is sent by the same user as the event that it replies to.