pub struct RoomMember { /* private fields */ }
The high-level RoomMember representation

Implementations

Gets the avatar of this member, if set.

Returns the avatar. If a thumbnail is requested no guarantee on the size of the image is given.

Arguments
  • format - The desired format of the avatar.
Example
let client = Client::new(homeserver).await.unwrap();
client.login_username(user, "password").send().await.unwrap();
let room_id = room_id!("!roomid:example.com");
let room = client.get_joined_room(&room_id).unwrap();
let members = room.members().await.unwrap();
let member = members.first().unwrap();
if let Some(avatar) = member.avatar(MediaFormat::File).await.unwrap() {
    std::fs::write("avatar.png", avatar);
}

Methods from Deref<Target = BaseRoomMember>

Get the unique user id of this member.

Get the original member event

Get the display name of the member if there is one.

Get the name of the member.

This returns either the display name or the local part of the user id if the member didn’t set a display name.

Get the avatar url of the member, if there is one.

Get the normalized power level of this member.

The normalized power level depends on the maximum power level that can be found in a certain room, it’s always in the range of 0-100.

Get the power level of this member.

Is the name that the member uses ambiguous in the room.

A name is considered to be ambiguous if at least one other member shares the same name.

Get the membership state of this member.