pub struct StoredThreadSubscription {
pub status: ThreadSubscriptionStatus,
pub bump_stamp: Option<u64>,
}Expand description
A thread subscription, as saved in the state store.
Fields
status: ThreadSubscriptionStatusCurrent status of the subscription.
bump_stamp: Option<u64>An optional bump stamp, as defined in the MSC; the higher the value, the most recent the thread subscription information is, and should be remembered.
If not set, this means it’s a user-provided thread subscription, for which we’re waiting validation from a server (e.g. through a remote echo via sync).