#[non_exhaustive]pub enum GlobalAccountDataEventType {
Direct,
IdentityServer,
InvitePermissionConfig,
IgnoredUserList,
PushRules,
SecretStorageDefaultKey,
SecretStorageKey(String),
MediaPreviewConfig,
UnstableMediaPreviewConfig,
RecentEmoji,
KeyBackup,
}Expand description
The type of GlobalAccountDataEvent this is.
This type can hold an arbitrary string. To build events with a custom type, convert it
from a string with ::from() / .into(). To check for events that are not available as a
documented variant here, use its string representation, obtained through .to_string().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Direct
m.direct
IdentityServer
m.identity_server
InvitePermissionConfig
m.invite_permission_config
IgnoredUserList
m.ignored_user_list
PushRules
m.push_rules
SecretStorageDefaultKey
m.secret_storage.default_key
SecretStorageKey(String)
m.secret_storage.key.*
MediaPreviewConfig
Available on crate feature
unstable-msc4278 only.m.media_preview_config
UnstableMediaPreviewConfig
Available on crate feature
unstable-msc4278 only.io.element.msc4278.media_preview_config
RecentEmoji
m.recent_emoji
KeyBackup
m.key_backup