pub struct SendQueueRoomError {
pub room_id: OwnedRoomId,
pub error: Arc<Error>,
pub is_recoverable: bool,
}Expand description
A specific room’s send queue ran into an error, and it has disabled itself.
Fields
room_id: OwnedRoomIdFor which room is the send queue failing?
error: Arc<Error>The error the room has ran into, when trying to send a request.
is_recoverable: boolWhether the error is considered recoverable or not.
An error that’s recoverable will disable the room’s send queue, while an unrecoverable error will be parked, until the user decides to do something about it.