pub struct SendRedactionHandle { /* private fields */ }Expand description
A handle to manipulate a redaction event that was scheduled to be sent to a room.
Implementations
Sourceimpl SendRedactionHandle
impl SendRedactionHandle
Sourcepub async fn abort(&self) -> Result<bool, RoomSendQueueStorageError>
pub async fn abort(&self) -> Result<bool, RoomSendQueueStorageError>
Abort the sending of the redaction.
Will return true if the redaction could be aborted, false if it’s been sent (and there’s no matching local echo anymore).