pub enum PollTimeout {
None,
Some(u32),
Default,
}Expand description
Define what kind of poll timeout SlidingSync must use.
How long to wait for new events […] If omitted the response is always returned immediately, even if there are no changes.
Variants
None
No timeout must be present.
Some(u32)
A timeout=X must be present, where X is in seconds and
represents how long to wait for new events.
Default
A timeout=X must be present, where X is the default value passed to
SlidingSyncBuilder::poll_timeout.