pub struct ThreadSubscriptionCatchupToken {
pub from: String,
pub to: Option<String>,
}Expand description
Tokens to use when catching up on thread subscriptions.
These tokens are created when the client receives some thread subscriptions from sync, but the sync indicates that there are more thread subscriptions available on the server. In this case, it’s expected that the client will call the MSC4308 companion endpoint to catch up (back-paginate) on previous thread subscriptions.
Fields
from: StringThe token to use as the lower bound when fetching new threads subscriptions.
In sliding sync, this is the prev_batch value of a sliding sync
response.
to: Option<String>The token to use as the upper bound when fetching new threads subscriptions.
In sliding sync, it must be set to the pos value of the sliding sync
request, which response received a prev_batch token.