[][src]Trait matrix_sdk::PossiblyRedactedExt

pub trait PossiblyRedactedExt {
    pub fn event_id(&self) -> &EventId;
pub fn origin_server_ts(&self) -> &SystemTime;
pub fn sender(&self) -> &UserId; }
This is supported on messages only.

Exposes some of the field access methods found in the event held by AnyPossiblyRedacted* enums.

This is just an extension trait to ease the use of certain event enums.

Required methods

pub fn event_id(&self) -> &EventId[src]

Access the redacted or full event's event_id field.

pub fn origin_server_ts(&self) -> &SystemTime[src]

Access the redacted or full event's origin_server_ts field.

pub fn sender(&self) -> &UserId[src]

Access the redacted or full event's sender field.

Loading content...

Implementors

impl PossiblyRedactedExt for AnyPossiblyRedactedSyncMessageEvent[src]

pub fn event_id(&self) -> &EventId[src]

Access the underlying event's event_id.

pub fn origin_server_ts(&self) -> &SystemTime[src]

Access the underlying event's origin_server_ts.

pub fn sender(&self) -> &UserId[src]

Access the underlying event's sender.

Loading content...