pub enum UrlOrQuery {
Url(Url),
Query(String),
}Expand description
A full URL or just the query part of a URL.
This is a convenience type to be able to access the query part of a URL from different sources.
Variants
Implementations
Sourceimpl UrlOrQuery
impl UrlOrQuery