pub trait IntoRawMessageLikeEventContent { }Expand description
The set of types that can be used with Room::send_raw.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IntoRawMessageLikeEventContent { }The set of types that can be used with Room::send_raw.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".