pub trait IntoRawStateEventContent { }Expand description
The set of types that can be used with Room::send_state_event_raw.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait IntoRawStateEventContent { }The set of types that can be used with Room::send_state_event_raw.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".