Struct matrix_sdk::attachment::Thumbnail
source · [−]pub struct Thumbnail<'a> {
pub data: &'a [u8],
pub content_type: &'a Mime,
pub info: Option<BaseThumbnailInfo>,
}Expand description
A thumbnail to upload and send for an attachment.
Fields
data: &'a [u8]The raw bytes of the thumbnail.
content_type: &'a MimeThe type of the thumbnail, this will be used as the content-type header.
info: Option<BaseThumbnailInfo>The metadata of the thumbnail.