Struct matrix_sdk::encryption::MediaEncryptionInfo
[−]pub struct MediaEncryptionInfo {
pub version: String,
pub key: JsonWebKey,
pub iv: Base64<Standard, Vec<u8, Global>>,
pub hashes: BTreeMap<String, Base64<Standard, Vec<u8, Global>>, Global>,
}Available on crate feature
e2e-encryption only.Expand description
Struct holding all the information that is needed to decrypt an encrypted file.
Fields
version: StringThe version of the encryption scheme.
key: JsonWebKeyThe web key that was used to encrypt the file.
iv: Base64<Standard, Vec<u8, Global>>The initialization vector that was used to encrypt the file.
hashes: BTreeMap<String, Base64<Standard, Vec<u8, Global>>, Global>The hashes that can be used to check the validity of the file.