pub enum DecodingError {
Header,
Utf8(FromUtf8Error),
Mode(u8),
Read(Error),
SharedSecret(usize),
Version(u8),
Keys(KeyError),
}Available on crate features
e2e-encryption and qrcode only.Expand description
Error type describing errors that happen while QR data is being decoded.
Variants
Header
The QR code data is missing the mandatory Matrix header.
Utf8(FromUtf8Error)
The QR code data is containing an invalid, non UTF-8, flow id.
Mode(u8)
The QR code data is using an unsupported or invalid verification mode.
Read(Error)
The QR code data does not contain all the necessary fields.
SharedSecret(usize)
The QR code data uses an invalid shared secret.
Version(u8)
The QR code data uses an invalid or unsupported version.
Keys(KeyError)
The QR code data doesn’t contain valid ed25519 keys.