Enum matrix_sdk::encryption::verification::ScanError
[−]pub enum ScanError {
Store(CryptoStoreError),
KeyMismatch {
expected: String,
found: String,
},
MissingCrossSigningIdentity(OwnedUserId),
MissingDeviceKeys(OwnedUserId, OwnedDeviceId),
FlowIdMismatch {
expected: String,
found: String,
},
}Available on crate features
e2e-encryption and qrcode only.Expand description
An error for the different failure modes that can happen during the validation of a scanned QR code.
Variants
Store(CryptoStoreError)
An IO error inside the crypto store happened during the validation of the QR code scan.
KeyMismatch
A key mismatch happened during the validation of the QR code scan.
MissingCrossSigningIdentity(OwnedUserId)
One of the users that is participating in this verification doesn’t have a valid cross signing identity.
MissingDeviceKeys(OwnedUserId, OwnedDeviceId)
The device of the user that is participating in this verification doesn’t have a valid device key.
FlowIdMismatch
Fields
expected: StringThe expected verification flow id.
found: StringThe verification flow id that we instead got.
The ID uniquely identifying this verification flow didn’t match to the one that has been scanned.