pub struct SasVerification { /* private fields */ }
Available on crate feature e2e-encryption only.
An object controlling the short auth string verification flow.

Implementations

Accept the interactive verification flow.

Accept the interactive verification flow with specific settings.

Arguments
  • settings - specific customizations to the verification flow.
Examples
use matrix_sdk::{
    encryption::verification::{AcceptSettings, SasVerification},
    ruma::events::key::verification::ShortAuthenticationString,
};

let sas = client
    .encryption()
    .get_verification(&user_id, flow_id)
    .await
    .and_then(|v| v.sas());

if let Some(sas) = sas {
    let only_decimal = AcceptSettings::with_allowed_methods(vec![
        ShortAuthenticationString::Decimal,
    ]);

    sas.accept_with_settings(only_decimal).await?;
}

Confirm that the short auth strings match on both sides.

Cancel the interactive verification flow because the short auth strings didn’t match on both sides.

Cancel the interactive verification flow.

Get the emoji version of the short auth string.

Examples
use matrix_sdk::{
    encryption::verification::{AcceptSettings, SasVerification},
    ruma::events::key::verification::ShortAuthenticationString,
};

let sas_verification = client
    .encryption()
    .get_verification(&user_id, flow_id)
    .await
    .and_then(|v| v.sas());

if let Some(emojis) = sas_verification.and_then(|s| s.emoji()) {
    let emoji_string = emojis
        .iter()
        .map(|e| format!("{:^12}", e.symbol))
        .collect::<Vec<_>>()
        .join("");

    let description = emojis
        .iter()
        .map(|e| format!("{:^12}", e.description))
        .collect::<Vec<_>>()
        .join("");

    println!("Do the emojis match?\n{emoji_string}\n{description}");
}

Get the decimal version of the short auth string.

Does this verification flow support emoji for the short authentication string.

Is the verification process done.

Are we in a state where we can show the short auth string.

Did we initiate the verification flow.

Get info about the cancellation if the verification flow has been cancelled.

Is the verification process canceled.

Get the other users device that we’re verifying.

Did this verification flow start from a verification request.

Is this a verification that is veryfying one of our own devices.

Get our own user id.

Get the user id of the other user participating in this verification flow.