EventHandlerResult

Trait EventHandlerResult 

pub trait EventHandlerResult: Sized { }
Return types supported for event handlers implement this trait.

It is not meant to be implemented outside of matrix-sdk.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl EventHandlerResult for ()

Source

impl<E: Debug + Display + 'static> EventHandlerResult for Result<(), E>

Implementors