pub struct RoomPowerLevelChanges {Show 13 fields
pub ban: Option<i64>,
pub invite: Option<i64>,
pub kick: Option<i64>,
pub redact: Option<i64>,
pub events_default: Option<i64>,
pub state_default: Option<i64>,
pub users_default: Option<i64>,
pub room_name: Option<i64>,
pub room_avatar: Option<i64>,
pub room_topic: Option<i64>,
pub space_child: Option<i64>,
pub beacon: Option<i64>,
pub beacon_info: Option<i64>,
}Expand description
A set of common power levels required for various operations within a room,
that can be applied as a single operation. When updating these
settings, any levels that are None will remain unchanged.
Fields
ban: Option<i64>The level required to ban a user.
invite: Option<i64>The level required to invite a user.
kick: Option<i64>The level required to kick a user.
redact: Option<i64>The level required to redact an event.
events_default: Option<i64>The default level required to send message events.
state_default: Option<i64>The default level required to send state events.
users_default: Option<i64>The default power level for every user in the room.
room_name: Option<i64>The level required to change the room’s name.
room_avatar: Option<i64>The level required to change the room’s avatar.
room_topic: Option<i64>The level required to change the room’s topic.
space_child: Option<i64>The level required to change the space’s children.
beacon: Option<i64>The level required to send a beacon (live location) message event.
beacon_info: Option<i64>The level required to send a beacon info state event.
Implementations